@@ -88,6 +88,10 @@ EC_API_EXTERN int ip_addr_get_prefix(struct ip_addr* netmask);
 EC_API_EXTERN void disable_ip_forward(void);
 EC_API_EXTERN u_int16 get_iface_mtu(const char *iface);
 
+#ifdef OS_LINUX
+EC_API_EXTERN void disable_interface_offload(void);
+#endif
+
 /********************/
 
 #ifdef WORDS_BIGENDIAN       
