@@ -1,5 +1,4 @@
 
-/* $Id: ec_mitm.h,v 1.9 2004/07/28 08:06:15 alor Exp $ */
 
 #ifndef EC_MITM_H
 #define EC_MITM_H
@@ -24,10 +23,10 @@ EC_API_EXTERN int is_mitm_active(char *name);
 
 /* an ugly hack to make accessible the arp poisoning lists to plugins */
 
-LIST_HEAD(arp_groups, hosts_list);
+LIST_HEAD(hosts_group, hosts_list);
 
-EC_API_EXTERN struct arp_groups arp_group_one;
-EC_API_EXTERN struct arp_groups arp_group_two;
+EC_API_EXTERN struct hosts_group arp_group_one;
+EC_API_EXTERN struct hosts_group arp_group_two;
 
 #endif
 
