@@ -15,8 +15,9 @@ enum {
    IL_TYPE_COOK     = 0x71,  /* linux cooked */
    IL_TYPE_PRISM    = 0x77,  /* prism2 header for wifi dumps */
    IL_TYPE_RADIOTAP = 0x7f,  /* radiotap header for wifi dumps */
+   IL_TYPE_PPI      = 0xc0   /* per packet information */
 };
-   
+
 /* link layer types */
 enum {
    LL_TYPE_IP   = 0x0800,
@@ -29,6 +30,8 @@ enum {
 /* network layer types */
 enum {
    NL_TYPE_ICMP  = 0x01,
+   NL_TYPE_IPIP  = 0x04,
+   NL_TYPE_IP6   = 0x29,
    NL_TYPE_ICMP6 = 0x3a,
    NL_TYPE_TCP   = 0x06,
    NL_TYPE_UDP   = 0x11,
@@ -110,6 +113,7 @@ enum {
    DHCP_OPT_SRV_ADDR    = 0x36,
    DHCP_OPT_RENEW_TIME  = 0x3a,
    DHCP_OPT_CLI_IDENT   = 0x3d,
+   DHCP_OPT_FQDN        = 0x51,
    DHCP_OPT_END         = 0xff,
    DHCP_OPT_MIN_LEN     = 0x12c,
 };
