@@ -89,19 +89,20 @@ static SLIST_HEAD(, http_field_entry) http_fields[2];
 /* protos */
 FUNC_DECODER(dissector_http);
 void http_init(void);
-static void Parse_Method_Get(u_char *ptr, struct packet_object *po);
-static void Parse_Method_Post(u_char *ptr, struct packet_object *po);
-static void Decode_Url(u_char *src);
-static int Check_CONNECT(u_char *ptr, struct packet_object *po);
-static void Find_Url(u_char *to_parse, char **ret);
-static void Find_Url_Referer(u_char *to_parse, char **ret);
-static void Parse_Post_Payload(u_char *ptr, struct http_status *conn_status, struct packet_object *po);
+static void Parse_Method_Get(char *ptr, struct packet_object *po);
+static void Parse_Method_Post(char *ptr, struct packet_object *po);
+static void Decode_Url(char *src);
+static int Check_CONNECT(char *ptr, struct packet_object *po);
+static void Find_Url(char *to_parse, char **ret);
+static void Find_Url_Referer(char *to_parse, char **ret);
+static void Parse_Post_Payload(char *ptr, struct http_status *conn_status, struct packet_object *po);
 static void Print_Pass(struct packet_object *po);
-static void Get_Banner(u_char *ptr, struct packet_object *po);
-static u_char Parse_Form(u_char *to_parse, char **ret, int mode);
+static void Get_Banner(char *ptr, struct packet_object *po);
+static u_char Parse_Form(char *to_parse, char **ret, int mode);
 static int Parse_Passport_Auth(char *ptr, char *from_here, struct packet_object *po);
 static int Parse_NTLM_Auth(char *ptr, char *from_here, struct packet_object *po);
 static int Parse_Basic_Auth(char *ptr, char *from_here, struct packet_object *po);
+static int Parse_User_Agent(char *ptr, char *end, char *from_here, struct packet_object *po);
 static char *unicodeToString(char *p, size_t len);
 static void dumpRaw(char *str, unsigned char *buf, size_t len);
 int http_fields_init(void);
@@ -144,7 +145,7 @@ FUNC_DECODER(dissector_http)
       return NULL;
 
    /* XXX - This way we won't catch ProxyAuth on CONNECT */
-   if (Check_CONNECT(ptr, PACKET))
+   if (Check_CONNECT((char*)ptr, PACKET))
       return NULL;         
 
    /* HOOK POINT: HOOK_PROTO_HTTP */
@@ -157,16 +158,18 @@ FUNC_DECODER(dissector_http)
       /* Check Proxy or WWW auth first
        * then password in the GET or POST.
        */
-      if ((from_here = strstr(ptr, "Authorization: Passport")) && 
-         Parse_Passport_Auth(ptr, from_here + strlen("Authorization: Passport"), PACKET));       
-      else if ((from_here = strstr(ptr, ": NTLM ")) && 
-         Parse_NTLM_Auth(ptr, from_here + strlen(": NTLM "), PACKET));
-      else if ((from_here = strstr(ptr, ": Basic ")) &&
-         Parse_Basic_Auth(ptr, from_here  + strlen(": Basic "), PACKET));
-      else if (!strncmp(ptr, "GET ", 4))
-         Parse_Method_Get(ptr + strlen("GET "), PACKET);
-      else if (!strncmp(ptr, "POST ", 5))
-         Parse_Method_Post(ptr + strlen("POST "), PACKET);
+      if ((from_here = strstr((const char*)ptr, "Authorization: Passport")) && 
+         Parse_Passport_Auth((char*)ptr, from_here + strlen("Authorization: Passport"), PACKET));       
+      else if ((from_here = strstr((const char*)ptr, ": NTLM ")) && 
+         Parse_NTLM_Auth((char*)ptr, from_here + strlen(": NTLM "), PACKET));
+      else if ((from_here = strstr((const char*)ptr, ": Basic ")) &&
+         Parse_Basic_Auth((char*)ptr, from_here  + strlen(": Basic "), PACKET));
+      else if ((from_here = strstr((const char*)ptr, "User-Agent: ")) &&
+          Parse_User_Agent((char*)ptr, end, from_here + strlen("User-Agent: "), PACKET));
+      else if (!strncmp((const char*)ptr, "GET ", 4))
+         Parse_Method_Get((char*)ptr + strlen("GET "), PACKET);
+      else if (!strncmp((const char*)ptr, "POST ", 5))
+         Parse_Method_Post((char*)ptr + strlen("POST "), PACKET);
       else {
          dissect_create_ident(&ident, PACKET, DISSECT_CODE(dissector_http));
          if (session_get(&s, ident, DISSECT_IDENT_LEN) == ESUCCESS) {
@@ -175,13 +178,13 @@ FUNC_DECODER(dissector_http)
             /* Are we waiting for post termination? */
             if (conn_status->c_status == POST_WAIT_DELIMITER ||
                 conn_status->c_status == POST_LAST_CHANCE)
-               Parse_Post_Payload(ptr, conn_status, PACKET);
+               Parse_Post_Payload((char*)ptr, conn_status, PACKET);
          }
          SAFE_FREE(ident);
       } 	 
    } else { /* Server Replies */
-      if (!strncmp(ptr, "HTTP", 4)) {
-         Get_Banner(ptr, PACKET);
+      if (!strncmp((const char*)ptr, "HTTP", 4)) {
+         Get_Banner((char*)ptr, PACKET);
 
          /* Since the server replies there's no need to
           * wait for POST termination or client response
@@ -193,8 +196,8 @@ FUNC_DECODER(dissector_http)
           * packet as HTTP header? Otherwise put these lines
           * out from the if (decrease performances, checks all pcks)
           */
-         if ((from_here = strstr(ptr, ": NTLM "))) 
-            Parse_NTLM_Auth(ptr, from_here + strlen(": NTLM "), PACKET);
+         if ((from_here = strstr((const char*)ptr, ": NTLM "))) 
+            Parse_NTLM_Auth((char*)ptr, from_here + strlen(": NTLM "), PACKET);
       }
    }
 
@@ -202,7 +205,7 @@ FUNC_DECODER(dissector_http)
 }
 
 /* Set the SSL flag (for ssl wrapper) when the CONNECT is finished */
-static int Check_CONNECT(u_char *ptr, struct packet_object *po)
+static int Check_CONNECT(char *ptr, struct packet_object *po)
 {
    void *ident = NULL;
    struct ec_session *s = NULL;
@@ -244,7 +247,7 @@ static int Check_CONNECT(u_char *ptr, struct packet_object *po)
 }
 
 /* Get the server banner from the headers */       
-static void Get_Banner(u_char *ptr, struct packet_object *po)
+static void Get_Banner(char *ptr, struct packet_object *po)
 {
    char *start, *end;
    u_int32 len;
@@ -350,7 +353,7 @@ static int Parse_Basic_Auth(char *ptr, char *from_here, struct packet_object *po
 
    user = ec_strtok(to_decode, ":", &pass); 
 
-   if (pass != NULL) {
+   if (pass != NULL && user != NULL) {
       po->DISSECTOR.user = strdup(user);
       po->DISSECTOR.pass = strdup(pass);	
  
@@ -367,6 +370,63 @@ static int Parse_Basic_Auth(char *ptr, char *from_here, struct packet_object *po
    return 1;
 }
 
+static int Parse_User_Agent(char* ptr, char* end, char *from_here, struct packet_object *po)
+{
+    // find the end of the line
+    const char* line_end = (const char*)memchr(from_here, '\n', end - from_here);
+    if (line_end == NULL) {
+        return 0;
+    }
+
+    unsigned int line_length = line_end - from_here;
+    const char* comment_begin = (const char*)memchr(from_here, '(', line_length);
+    if (comment_begin == NULL || ((comment_begin + 1) >= end)) {
+        // no comments found
+        return 0;
+    }
+    ++comment_begin;
+
+    const char* comment_end = (const char*)memchr(comment_begin, ')', line_end - comment_begin);
+    if (comment_end == NULL) {
+        // couldn't find the close on the comment
+        return 0;
+    }
+
+    const char* os = NULL;
+    while (os == NULL && comment_begin != NULL) {
+        unsigned int comment_length = comment_end - comment_begin;
+        if ((comment_length > 10 && strncmp(comment_begin, "Windows NT", 10) == 0) ||
+            (comment_length > 9 && strncmp(comment_begin, "Intel Mac", 9) == 0) ||
+            (comment_length > 7 && strncmp(comment_begin, "PPC Mac", 7) == 0) ||
+            (comment_length > 10 && strncmp(comment_begin, "CPU iPhone", 10) == 0) ||
+            (comment_length > 8 && strncmp(comment_begin, "Android", 7) == 0) ||
+            (comment_length > 5 && strncmp(comment_begin, "CrOS", 4) == 0) || // Chrome OS
+            (comment_length > 5 && strncmp(comment_begin, "Linux", 5) == 0)) {
+            os = comment_begin;
+        }
+
+        if (os == NULL) {
+            comment_begin = memchr(comment_begin, ';', comment_end - comment_begin);
+            if (comment_begin != NULL && ((comment_begin + 2) < comment_end)) {
+                // skip the ; and the ' '
+                comment_begin += 2;
+            }
+        } else {
+            const char* the_end = memchr(comment_begin, ';', comment_end - comment_begin);
+            if (the_end != NULL) {
+                comment_end = the_end;
+            }
+
+            SAFE_CALLOC(po->DISSECTOR.os, 1, (comment_end - os) + 1);
+            memcpy(po->DISSECTOR.os, os, comment_end - os);
+            po->DISSECTOR.os[comment_end - os] = 0;
+        }
+    }
+
+    // always return 0 so the main loop drops down to get/post
+    return 0;
+}
+
 /* Parse NTLM challenge and response for both Proxy and WWW Auth */ 
 static int Parse_NTLM_Auth(char *ptr, char *from_here, struct packet_object *po)
 {
@@ -412,7 +472,7 @@ static int Parse_NTLM_Auth(char *ptr, char *from_here, struct packet_object *po)
       SAFE_CALLOC(s->data, 1, sizeof(struct http_status));                  
       conn_status = (struct http_status *) s->data;
       conn_status->c_status = NTLM_WAIT_RESPONSE;
-      dumpRaw(conn_status->c_data, challenge_struct->challengeData, 8);
+      dumpRaw((char*)conn_status->c_data, challenge_struct->challengeData, 8);
       session_put(s);
 
    } else if (msgType==3) {   
@@ -442,7 +502,7 @@ static int Parse_NTLM_Auth(char *ptr, char *from_here, struct packet_object *po)
             dumpRaw(outstr,((unsigned char*)response_struct)+IVAL(&response_struct->ntResponse.offset,0), 24);	       	    
             outstr[48] = ':';
             outstr += 49;
-            strcat(po->DISSECTOR.pass, conn_status->c_data);
+            strcat(po->DISSECTOR.pass, (const char*)conn_status->c_data);
 
             /* Are we authenticating to the proxy or to a website? */
             if (Proxy_Auth)
@@ -462,7 +522,7 @@ static int Parse_NTLM_Auth(char *ptr, char *from_here, struct packet_object *po)
 
 
 /* Deal with POST continuation */
-static void Parse_Post_Payload(u_char *ptr, struct http_status *conn_status, struct packet_object *po)
+static void Parse_Post_Payload(char *ptr, struct http_status *conn_status, struct packet_object *po)
 { 
    char *user=NULL, *pass=NULL;
 
@@ -480,7 +540,7 @@ static void Parse_Post_Payload(u_char *ptr, struct http_status *conn_status, str
       if (Parse_Form(ptr, &user, USER) && Parse_Form(ptr, &pass, PASS)) {
          po->DISSECTOR.user = user;
          po->DISSECTOR.pass = pass;
-         po->DISSECTOR.info = strdup(conn_status->c_data);
+         po->DISSECTOR.info = strdup((const char*)conn_status->c_data);
          dissect_wipe_session(po, DISSECT_CODE(dissector_http));
          Print_Pass(po);
       } else
@@ -490,7 +550,7 @@ static void Parse_Post_Payload(u_char *ptr, struct http_status *conn_status, str
 
 
 /* Parse the POST header */
-static void Parse_Method_Post(u_char *ptr, struct packet_object *po) 
+static void Parse_Method_Post(char *ptr, struct packet_object *po) 
 {
    char *url = NULL;
    struct ec_session *s = NULL;
@@ -508,7 +568,7 @@ static void Parse_Method_Post(u_char *ptr, struct packet_object *po)
    SAFE_CALLOC(s->data, 1, sizeof(struct http_status));                  
    conn_status = (struct http_status *) s->data;
    conn_status->c_status = POST_WAIT_DELIMITER;
-   strlcpy(conn_status->c_data, url, sizeof(conn_status->c_data));
+   strlcpy((char*)conn_status->c_data, url, sizeof(conn_status->c_data));
    session_put(s);
 
    Parse_Post_Payload(ptr, conn_status, po);
@@ -518,10 +578,10 @@ static void Parse_Method_Post(u_char *ptr, struct packet_object *po)
 
 
 /* Search for passwords in the URL */
-static void Parse_Method_Get(u_char *ptr, struct packet_object *po) 
+static void Parse_Method_Get(char *ptr, struct packet_object *po) 
 {
-   u_char *to_parse = NULL;
-   u_char *delimiter = NULL;
+   char *to_parse = NULL;
+   char *delimiter = NULL;
    char *user = NULL;
    char *pass = NULL;
    
@@ -560,9 +620,9 @@ http_get_failure:
 
 
 /* Match users or passwords in a string */
-static u_char Parse_Form(u_char *to_parse, char **ret, int mode)
+static u_char Parse_Form(char *to_parse, char **ret, int mode)
 {
-   u_char *q;
+   char *q;
    struct http_field_entry *d;
 
    /* Strip the '?' from a GET method */
@@ -591,7 +651,7 @@ static u_char Parse_Form(u_char *to_parse, char **ret, int mode)
             if ((q = strchr(*ret, '&')))
                *q = 0; 
 
-            Decode_Url((u_char *)*ret);
+            Decode_Url(*ret);
             return 1;
          }
       } while ( (q = strchr(q, '&')) );
@@ -602,9 +662,9 @@ static u_char Parse_Form(u_char *to_parse, char **ret, int mode)
 
 
 /* Unescape the string */
-static void Decode_Url(u_char *src)
+static void Decode_Url(char *src)
 {
-   u_char t[3];
+   char t[3];
    u_int32 i, j, ch;
 
    /* Paranoid test */
@@ -621,16 +681,16 @@ static void Decode_Url(u_char *src)
          ch = strtoul(t, NULL, 16);
          i += 2;
       }
-      src[j] = (u_char)ch;
+      src[j] = (char)ch;
    }
    src[j] = 0;
 }
 
 
 /* Gets the URL from the headers */
-static void Find_Url_Referer(u_char *to_parse, char **ret) 
+static void Find_Url_Referer(char *to_parse, char **ret) 
 {
-   u_char *fromhere, *page=NULL, *host=NULL;     
+   char *fromhere, *page=NULL, *host=NULL;     
    u_int32 len;
    char *tok;
 
@@ -658,14 +718,14 @@ static void Find_Url_Referer(u_char *to_parse, char **ret)
       SAFE_FREE(host);            
    }    
    
-   Decode_Url((u_char *)*ret);
+   Decode_Url(*ret);
 }
 
 
 /* Gets the URL from the request */
-static void Find_Url(u_char *to_parse, char **ret) 
+static void Find_Url(char *to_parse, char **ret) 
 {
-   u_char *fromhere, *page=NULL, *host=NULL;     
+   char *fromhere, *page=NULL, *host=NULL;     
    u_int32 len;
    char *tok;
 
@@ -685,7 +745,7 @@ static void Find_Url(u_char *to_parse, char **ret)
       host = strdup( fromhere + strlen("Host: ") );
       ec_strtok(host, "\r", &tok);
    } else 
-      host = (u_char*)strdup("");
+      host = strdup("");
 	 
    len = strlen(page) + strlen(host) + 2;
    SAFE_CALLOC(*ret, len, sizeof(char));
@@ -694,7 +754,7 @@ static void Find_Url(u_char *to_parse, char **ret)
    SAFE_FREE(page);
    SAFE_FREE(host);            
        
-   Decode_Url((u_char *)*ret);
+   Decode_Url(*ret);
 }
 
 /* Print the passwords from the PO */
