@@ -55,7 +55,7 @@ FUNC_DECODER(dissector_napster)
    DECLARE_DISP_PTR_END(ptr, end);
    char tmp[MAX_ASCII_ADDR_LEN];
    struct nap_hdr *nap;
-   u_char *tbuf, *user, *pass, *client;
+   char *tbuf, *user, *pass, *client;
    size_t tlen;
    char *tok;
 
@@ -88,14 +88,14 @@ FUNC_DECODER(dissector_napster)
    DEBUG_MSG("\tDissector_napster LOGIN\n");
    
    /* move after the header */
-   ptr = (char *)(nap + 1);
+   ptr = (u_char *)(nap + 1);
    
    /* get the len of the command */
    tlen = phtos(&nap->len);
 
    /* use a temp buffer to operate on */
    SAFE_CALLOC(tbuf, tlen + 1, sizeof(char));
-   strlcpy(tbuf, ptr, tlen + 1);   
+   strlcpy(tbuf, (const char*)ptr, tlen + 1);   
 
    /* get the user */
    if ((user = ec_strtok(tbuf, " ", &tok)) == NULL)
