@@ -166,7 +166,7 @@ int hex_format(const u_char *buf, size_t len, u_char *dst)
   
    /* some sanity checks */
    if (len == 0 || buf == NULL) {
-      strncpy(dst, "", 1);
+      strncpy((char*)dst, "", 1);
       return 0;
    }
   
@@ -174,32 +174,32 @@ int hex_format(const u_char *buf, size_t len, u_char *dst)
    memset(dst, 0, hex_len(len));
    
    for (i = 0; i < len; i += HEX_CHAR_PER_LINE) {
-           snprintf(dst, strlen(dst)+5, "%s %04x: ", dst, i );
+           snprintf((char*)dst, strlen((char*)dst)+5, "%s %04x: ", dst, i );
            jm = len - i;
            jm = jm > HEX_CHAR_PER_LINE ? HEX_CHAR_PER_LINE : jm;
 
            for (j = 0; j < jm; j++) {
                    if ((j % 2) == 1) {
-                      snprintf(dst, strlen(dst) + 3, "%s%02x ", dst, (u_char) buf[i+j]);
+                      snprintf((char*)dst, strlen((char*)dst) + 3, "%s%02x ", dst, buf[i+j]);
                    } else {
-                      snprintf(dst, strlen(dst)+3, "%s%02x", dst, (u_char) buf[i+j]);
+                      snprintf((char*)dst, strlen((char*)dst)+3, "%s%02x", dst, buf[i+j]);
                    }
            }
            for (; j < HEX_CHAR_PER_LINE; j++) {
                    if ((j % 2) == 1) {
-                      strcat(dst, "   ");
+                      strcat((char*)dst, "   ");
                    } else {
-                      strcat(dst, "  ");
+                      strcat((char*)dst, "  ");
                    }
            } 
-           strcat(dst, " ");
+           strcat((char*)dst, " ");
 
            for (j = 0; j < jm; j++) {
-                   c = (u_char) buf[i+j];
+                   c = buf[i+j];
                    c = isprint(c) ? c : '.';
-                   dim = snprintf(dst, strlen(dst)+1, "%s%c", dst, c);
+                   dim = snprintf((char*)dst, strlen((char*)dst)+1, "%s%c", dst, c);
            }
-           strcat(dst, "\n");
+           strcat((char*)dst, "\n");
    }
 
    return dim + 1;
@@ -216,7 +216,7 @@ int ascii_format(const u_char *buf, size_t len, u_char *dst)
    
    /* some sanity checks */
    if (len == 0 || buf == NULL) {
-      strncpy(dst, "", 1);
+      strncpy((char*)dst, "", 1);
       return 0;
    }
 
@@ -241,7 +241,7 @@ int text_format(const u_char *buf, size_t len, u_char *dst)
    
    /* some sanity checks */
    if (len == 0 || buf == NULL) {
-      strncpy(dst, "", 1);
+      strncpy((char*)dst, "", 1);
       return 0;
    }
 
@@ -276,7 +276,7 @@ int ebcdic_format(const u_char *buf, size_t len, u_char *dst)
    
    /* some sanity checks */
    if (len == 0 || buf == NULL) {
-      strncpy(dst, "", 1);
+      strncpy((char*)dst, "", 1);
       return 0;
    }
    
@@ -297,7 +297,7 @@ int html_format(const u_char *buf, size_t len, u_char *dst)
    
    /* some sanity checks */
    if (len == 0 || buf == NULL) {
-      strncpy(dst, "", 1);
+      strncpy((char*)dst, "", 1);
       return 0;
    }
 
@@ -323,7 +323,7 @@ int bin_format(const u_char *buf, size_t len, u_char *dst)
 {
    /* some sanity checks */
    if (len == 0 || buf == NULL) {
-      strncpy(dst, "", 1);
+      strncpy((char*)dst, "", 1);
       return 0;
    }
    
@@ -339,7 +339,7 @@ int bin_format(const u_char *buf, size_t len, u_char *dst)
 
 int zero_format(const u_char *buf, size_t len, u_char *dst)
 {
-   strncpy(dst, "", 1);
+   strncpy((char*)dst, "", 1);
    return 0;
 }
 
@@ -373,7 +373,7 @@ int utf8_format(const u_char *buf, size_t len, u_char *dst)
 
    /* some sanity checks */
    if (len == 0 || buf == NULL) {
-      strncpy(dst, "", 1);
+      strncpy((char*)dst, "", 1);
       return 0;
    }
 
@@ -409,20 +409,20 @@ int set_utf8_encoding(u_char *fromcode)
 
    DEBUG_MSG("set_utf8_encoding: %s", fromcode);
       
-   if (fromcode == NULL || strlen(fromcode) < 1)
+   if (fromcode == NULL || strlen((const char*)fromcode) < 1)
       return -EINVALID;
 
    SAFE_FREE(utf8_encoding);
 
    /* make sure encoding type is supported */
-   cd = iconv_open("UTF-8", fromcode);
+   cd = iconv_open("UTF-8", (const char*)fromcode);
    
    if (cd == (iconv_t)(-1))
       SEMIFATAL_ERROR("The conversion from %s to UTF-8 is not supported.", fromcode);
    
    iconv_close(cd);
 
-   utf8_encoding = strdup(fromcode);
+   utf8_encoding = strdup((const char*)fromcode);
 
    return ESUCCESS;
 #endif
