@@ -102,7 +102,7 @@ void print_host(struct host_profile *h)
       
    if (h->type & FP_HOST_LOCAL || h->type == FP_UNKNOWN) {
       fprintf(stdout, " MAC address  : %s \n", mac_addr_ntoa(h->L2_addr, tmp));
-      fprintf(stdout, " MANUFACTURER : %s \n\n", manuf_search(h->L2_addr));
+      fprintf(stdout, " MANUFACTURER : %s \n\n", manuf_search((const char*)h->L2_addr));
    }
 
    fprintf(stdout, " DISTANCE     : %d   \n", h->distance);
@@ -119,7 +119,7 @@ void print_host(struct host_profile *h)
       
    
    fprintf(stdout, " FINGERPRINT      : %s\n", h->fingerprint);
-   if (fingerprint_search(h->fingerprint, os) == ESUCCESS)
+   if (fingerprint_search((const char*)h->fingerprint, os) == ESUCCESS)
       fprintf(stdout, " OPERATING SYSTEM : %s \n\n", os);
    else {
       fprintf(stdout, " OPERATING SYSTEM : unknown fingerprint (please submit it) \n");
@@ -172,7 +172,7 @@ void print_host_xml(struct host_profile *h)
    
    if (h->type & FP_HOST_LOCAL || h->type == FP_UNKNOWN) {
       fprintf(stdout, "\t\t<mac>%s</mac>\n", mac_addr_ntoa(h->L2_addr, tmp));
-      fprintf(stdout, "\t\t<manuf>%s</manuf>\n", manuf_search(h->L2_addr));
+      fprintf(stdout, "\t\t<manuf>%s</manuf>\n", manuf_search((const char*)h->L2_addr));
    }
    
    fprintf(stdout, "\t\t<distance>%d</distance>\n", h->distance);
@@ -188,8 +188,8 @@ void print_host_xml(struct host_profile *h)
       fprintf(stdout, "\t\t<type>unknown</type>\n");
   
    
-   if (strcmp(h->fingerprint, "")) {
-      if (fingerprint_search(h->fingerprint, os) == ESUCCESS) {
+   if (strcmp((const char*)h->fingerprint, "")) {
+      if (fingerprint_search((const char*)h->fingerprint, os) == ESUCCESS) {
          fprintf(stdout, "\t\t<fingerprint type=\"known\">%s</fingerprint>\n", h->fingerprint);
          fprintf(stdout, "\t\t<os type=\"exact\">%s</os>\n", os);
       } else {
