@@ -17,7 +17,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_plugins.c,v 1.39 2004/07/12 19:57:26 alor Exp $
 */
 
 #include <ec.h>
@@ -94,19 +93,19 @@ int plugin_load_single(char *path, char *name)
    DEBUG_MSG("plugin_load_single: %s", file);
    
    /* load the plugin */
-   handle = lt_dlopen(file);
+   handle = dlopen(file, RTLD_NOW|RTLD_LOCAL);
 
    if (handle == NULL) {
-      DEBUG_MSG("plugin_load_single - %s - lt_dlopen() | %s", file, lt_dlerror());
+      DEBUG_MSG("plugin_load_single - %s - dlopen() | %s", file, dlerror());
       return -EINVALID;
    }
    
    /* find the loading function */
-   plugin_load = lt_dlsym(handle, SYM_PREFIX "plugin_load");
+   plugin_load = dlsym(handle, SYM_PREFIX "plugin_load");
    
    if (plugin_load == NULL) {
-      DEBUG_MSG("plugin_load_single - %s - lt_dlsym() | %s", file, lt_dlerror());
-      lt_dlclose(handle);
+      DEBUG_MSG("plugin_load_single - %s - lt_dlsym() | %s", file, dlerror());
+      dlclose(handle);
       return -EINVALID;
    }
 
@@ -131,7 +130,7 @@ int plugin_filter(struct dirent *d)
 int plugin_filter(const struct dirent *d)
 #endif
 {
-   if ( match_pattern(d->d_name, PLUGIN_PATTERN LTDL_SHLIB_EXT) )
+   if ( match_pattern(d->d_name, PLUGIN_PATTERN) )
       return 1;
 
    return 0;
@@ -151,8 +150,6 @@ void plugin_load_all(void)
    
    DEBUG_MSG("plugin_loadall");
 
-   if (lt_dlinit() != 0)
-      ERROR_MSG("lt_dlinit()");
 #ifdef OS_WINDOWS
    /* Assume .DLLs are under "<ec_root>/lib". This should be unified for
     * all; ec_get_lib_path()?
@@ -223,12 +220,12 @@ void plugin_unload_all(void)
    
    while (SLIST_FIRST(&plugin_head) != NULL) {
       p = SLIST_FIRST(&plugin_head);
-      lt_dlclose(p->handle);
+      if(plugin_is_activated(p->ops->name) == 1)
+		plugin_fini(p->ops->name);
+      dlclose(p->handle);
       SLIST_REMOVE_HEAD(&plugin_head, next);
       SAFE_FREE(p);
    }
-   
-   lt_dlexit();
 #endif
 }
 
@@ -243,7 +240,7 @@ int plugin_register(void *handle, struct plugin_ops *ops)
 
    /* check for ettercap API version */
    if (strcmp(ops->ettercap_version, EC_VERSION)) {
-      lt_dlclose(handle);
+      dlclose(handle);
       return -EVERSION;
    }
    
@@ -251,7 +248,7 @@ int plugin_register(void *handle, struct plugin_ops *ops)
    SLIST_FOREACH(pl, &plugin_head, next) {
       /* same name and same version */
       if (!strcmp(ops->name, pl->ops->name) && !strcmp(ops->version, pl->ops->version)) {
-         lt_dlclose(handle);
+         dlclose(handle);
          return -EDUPLICATE;
       }
    }
