@@ -17,7 +17,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_sniff_unified.c,v 1.23 2004/06/11 08:44:25 lordnaga Exp $
 */
 
 #include <ec.h>
@@ -52,14 +51,22 @@ void start_unified_sniff(void)
    USER_MSG("Starting Unified sniffing...\n\n");
    
    /* create the timeouter thread */
-   if (!GBL_OPTIONS->read && ec_thread_getpid("timer") == 0)
-      ec_thread_new("timer", "conntrack timeouter", &conntrack_timeouter, NULL);
+   if (!GBL_OPTIONS->read) { 
+      pthread_t pid;
+      
+      pid = ec_thread_getpid("timer");
+      if (pthread_equal(pid, EC_PTHREAD_NULL))
+         ec_thread_new("timer", "conntrack timeouter", &conntrack_timeouter, NULL);
+   }
 
    /* create the thread for packet capture */
-   ec_thread_new("capture", "pcap handler and packet decoder", &capture, GBL_OPTIONS->iface);
+   capture_start(GBL_IFACE);
+
+   if(GBL_OPTIONS->secondary)
+      secondary_sources_foreach(capture_start);
 
    /* start ssl_wrapper thread */
-   if (!GBL_OPTIONS->read && !GBL_OPTIONS->unoffensive && !GBL_OPTIONS->only_mitm)
+   if (!GBL_OPTIONS->read && !GBL_OPTIONS->unoffensive && !GBL_OPTIONS->only_mitm && GBL_OPTIONS->ssl_mitm)
       ec_thread_new("sslwrap", "wrapper for ssl connections", &sslw_start, NULL);
 
    GBL_SNIFF->active = 1;
@@ -80,12 +87,14 @@ void stop_unified_sniff(void)
       return;
    }
   
-   /* get the pid and kill it */
-   if ((pid = ec_thread_getpid("capture")) != 0)
-      ec_thread_destroy(pid);
+   /* kill it */
+   capture_stop(GBL_IFACE);
 
-   /* get the pid and kill it */
-   if ((pid = ec_thread_getpid("sslwrap")) != 0)
+   if(GBL_OPTIONS->secondary)
+      secondary_sources_foreach(capture_stop);
+   
+   pid = ec_thread_getpid("sslwrap");
+   if (!pthread_equal(pid, EC_PTHREAD_NULL))
       ec_thread_destroy(pid);
 
    USER_MSG("Unified sniffing was stopped.\n");
@@ -97,12 +106,20 @@ void stop_unified_sniff(void)
 void forward_unified_sniff(struct packet_object *po)
 {
    /* if it was not initialized, no packet are forwardable */
-   if (!GBL_LNET->lnet)
-      return;
-
-   /* if the interface was not configured, no packet are forwardable */
-   if (!GBL_IFACE->configured)
-      return;
+   switch(ntohs(po->L3.proto)) {
+      case LL_TYPE_IP:
+         if(!GBL_LNET->lnet_IP4)
+            return;
+         if(!(GBL_IFACE->has_ipv4))
+            return;
+         break;
+      case LL_TYPE_IP6:
+         if(!GBL_LNET->lnet_IP6)
+            return;
+         if(!(GBL_IFACE->has_ipv6))
+            return;
+         break;
+   }
    
    /* if unoffensive is set, don't forward any packet */
    if (GBL_OPTIONS->unoffensive || GBL_OPTIONS->read)
@@ -132,16 +149,16 @@ void forward_unified_sniff(struct packet_object *po)
 void unified_check_forwarded(struct packet_object *po) 
 {
    /* the interface was not configured, the packets are not forwardable */
-   if (!GBL_IFACE->configured)
+   if (!GBL_IFACE->is_ready)
       return;
    
    /* 
     * dont sniff forwarded packets (equal mac, different ip) 
     * but only if we are on live connections
     */
-   if ( GBL_CONF->skip_forwarded && !GBL_OPTIONS->read &&
-        !memcmp(GBL_IFACE->mac, po->L2.src, MEDIA_ADDR_LEN) &&
-        ip_addr_cmp(&GBL_IFACE->ip, &po->L3.src) ) {
+   if (GBL_CONF->skip_forwarded && !GBL_OPTIONS->read &&
+       !memcmp(GBL_IFACE->mac, po->L2.src, MEDIA_ADDR_LEN) &&
+       ip_addr_is_ours(&po->L3.src) != EFOUND) {
       po->flags |= PO_FORWARDED;
    }
 }
@@ -160,7 +177,7 @@ void unified_set_forwardable(struct packet_object *po)
     */
    if (!memcmp(GBL_IFACE->mac, po->L2.dst, MEDIA_ADDR_LEN) &&
        memcmp(GBL_IFACE->mac, po->L2.src, MEDIA_ADDR_LEN) &&
-       ip_addr_cmp(&GBL_IFACE->ip, &po->L3.dst) ) {
+       ip_addr_is_ours(&po->L3.dst) != EFOUND) {
       po->flags |= PO_FORWARDABLE;
    }
    
