@@ -17,7 +17,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_curses.c,v 1.46 2004/05/12 15:27:06 alor Exp $
 */
 
 #include <ec.h>
@@ -48,7 +47,8 @@ static void curses_msg(const char *msg);
 static void curses_error(const char *msg);
 static void curses_fatal_error(const char *msg);
 void curses_input(const char *title, char *input, size_t n, void (*callback)(void));
-static void curses_progress(char *title, int value, int max);
+static int curses_progress(char *title, int value, int max);
+static void curses_update(int target);
 
 static void curses_setup(void);
 static void curses_exit(void);
@@ -64,6 +64,7 @@ static void curses_unified_sniff(void);
 static void curses_bridged_sniff(void);
 static void bridged_sniff(void);
 static void curses_pcap_filter(void);
+static void curses_set_netmask(void);
 
 
 /*******************************************/
@@ -85,6 +86,7 @@ void set_curses_interface(void)
    ops.fatal_error = &curses_fatal_error;
    ops.input = &curses_input;
    ops.progress = &curses_progress;
+   ops.update = &curses_update;
    ops.type = UI_CURSES;
    
    ui_register(&ops);
@@ -172,7 +174,7 @@ static void curses_msg(const char *msg)
    if (sysmsg_win == NULL)
       return;
 
-   wdg_scroll_print(sysmsg_win, EC_COLOR, (char *)msg);
+   wdg_scroll_print(sysmsg_win, EC_COLOR, "%s", (char *)msg);
 }
 
 
@@ -245,9 +247,10 @@ void curses_input(const char *title, char *input, size_t n, void (*callback)(voi
 /* 
  * implement the progress bar 
  */
-static void curses_progress(char *title, int value, int max)
+static int curses_progress(char *title, int value, int max)
 {
    static wdg_t *per = NULL;
+   int ret;
    
    /* the first time, create the object */
    if (per == NULL) {
@@ -266,15 +269,48 @@ static void curses_progress(char *title, int value, int max)
    } 
    
    /* the subsequent calls have to only update the object */
-   wdg_percentage_set(per, value, max);
+   ret = wdg_percentage_set(per, value, max);
    wdg_update_screen();
 
-   /* 
-    * the object is self-destructing... 
-    * so we have only to set the pointer to null
-    */
-   if (value == max)
-      per = NULL;
+   switch (ret) {
+      case WDG_PERCENTAGE_FINISHED:
+         /* 
+          * the object is self-destructing... 
+          * so we have only to set the pointer to null
+          */
+         per = NULL;
+         return UI_PROGRESS_FINISHED;
+         break;
+         
+      case WDG_PERCENTAGE_INTERRUPTED: 
+         /*
+          * the user has requested to stop the current task.
+          * the percentage was self-destructed, we have to 
+          * set the pointer to null and return the proper value
+          */
+         per = NULL;
+         return UI_PROGRESS_INTERRUPTED;
+         break;
+         
+      case WDG_PERCENTAGE_UPDATED: 
+         return UI_PROGRESS_UPDATED;
+         break;
+   }
+  
+   return UI_PROGRESS_UPDATED;
+}
+
+/*
+ * process an update notification
+ */
+static void curses_update(int target)
+{
+   switch(target) {
+      case UI_UPDATE_HOSTLIST:   curses_hosts_update();
+                                 break;
+
+      default:                   break;
+   }
 }
 
 /*
@@ -360,14 +396,15 @@ static void curses_setup(void)
    struct wdg_menu live[] = { {"Sniff",               'S', "",  NULL},
                               {"Unified sniffing...", 'U', "U", curses_unified_sniff},
                               {"Bridged sniffing...", 'B', "B", curses_bridged_sniff},
-                              {"-",                   0,   "",  NULL},
+                              {"-",                    0,   "",  NULL},
                               {"Set pcap filter...",  'p', "p", curses_pcap_filter},
                               {NULL, 0, NULL, NULL},
                             };
    
-   struct wdg_menu options[] = { {"Options",      'O', "",          NULL},
-                                 {"Unoffensive",   0,  tag_unoff,   toggle_unoffensive},
-                                 {"Promisc mode",  0,  tag_promisc, toggle_nopromisc},
+   struct wdg_menu options[] = { {"Options",       'O', "",          NULL},
+                                 {"Unoffensive",    0,  tag_unoff,   toggle_unoffensive},
+                                 {"Promisc mode",   0,  tag_promisc, toggle_nopromisc},
+                                 {"Set netmask",   'n', "n" , curses_set_netmask},
                                  {NULL, 0, NULL, NULL},
                                };
    
@@ -384,6 +421,7 @@ static void curses_setup(void)
    wdg_menu_add(menu, file);
    wdg_menu_add(menu, live);
    wdg_menu_add(menu, options);
+   wdg_menu_add(menu, menu_help);
    wdg_draw_object(menu);
    
    DEBUG_MSG("curses_setup: menu created");
@@ -458,7 +496,7 @@ static void read_pcapfile(char *path, char *file)
    
    SAFE_CALLOC(GBL_OPTIONS->pcapfile_in, strlen(path)+strlen(file)+2, sizeof(char));
 
-   sprintf(GBL_OPTIONS->pcapfile_in, "%s/%s", path, file);
+   snprintf(GBL_OPTIONS->pcapfile_in, strlen(path)+strlen(file)+2, "%s/%s", path, file);
 
    /* check if the file is good */
    if (is_pcap_file(GBL_OPTIONS->pcapfile_in, errbuf) != ESUCCESS) {
@@ -553,7 +591,13 @@ static void curses_bridged_sniff(void)
    /* if the user has not specified an interface, get the first one */
    if (GBL_OPTIONS->iface == NULL) {
       SAFE_CALLOC(GBL_OPTIONS->iface, IFACE_LEN, sizeof(char));
-      strncpy(GBL_OPTIONS->iface, pcap_lookupdev(err), IFACE_LEN - 1);
+   /* if ettercap is started with a non root account pcap_lookupdev(err) == NULL (Fedora bug 783675) */
+      if(pcap_lookupdev(err) != NULL)
+         strncpy(GBL_OPTIONS->iface, pcap_lookupdev(err), IFACE_LEN - 1);
+   /* else
+	here we have to gracefully exit, since we don't have any available interface
+  */
+	
    }
    
    SAFE_CALLOC(GBL_OPTIONS->iface_bridge, IFACE_LEN, sizeof(char));
@@ -598,6 +642,33 @@ static void curses_pcap_filter(void)
    curses_input("Pcap filter :", GBL_PCAP->filter, PCAP_FILTER_LEN, NULL);
 }
 
+/*
+ * set a different netmask than the system one 
+ */
+static void curses_set_netmask(void)
+{
+   struct in_addr net;
+   
+   DEBUG_MSG("curses_set_netmask");
+  
+   if (GBL_OPTIONS->netmask == NULL)
+      SAFE_CALLOC(GBL_OPTIONS->netmask, IP_ASCII_ADDR_LEN, sizeof(char));
+
+   /* 
+    * no callback, the filter is set but we have to return to
+    * the interface for other user input
+    */
+   curses_input("Netmask :", GBL_OPTIONS->netmask, IP_ASCII_ADDR_LEN, NULL);
+
+   /* sanity check */
+   if (strcmp(GBL_OPTIONS->netmask, "") && inet_aton(GBL_OPTIONS->netmask, &net) == 0)
+      ui_error("Invalid netmask %s", GBL_OPTIONS->netmask);
+            
+   /* if no netmask was specified, free it */
+   if (!strcmp(GBL_OPTIONS->netmask, ""))
+      SAFE_FREE(GBL_OPTIONS->netmask);
+            
+}
 
 /* EOF */
 
